@@ -52,10 +52,20 @@ public:
 
 	/// Often refered to as the protocol prefix, e.g. ftp://
 	std::string scheme_;
+
+	/// Optional user part of the authority
 	std::string user_;
+
+	/// Optional password part of the authority
 	std::string pass_;
+
+	/// Hostname, or IP address literal
 	std::string host_;
+
+	/// Optional Port if non-zero
 	unsigned short port_{};
+
+	/// Optional path, must start with a slash if set
 	std::string path_;
 
 	/**
@@ -84,7 +94,7 @@ public:
 	 */
 	void resolve(uri const& base);
 private:
-	bool parse_authority(std::string && authority);
+	bool FZ_PRIVATE_SYMBOL parse_authority(std::string && authority);
 };
 
 /**
@@ -108,6 +118,8 @@ public:
 
 	std::map<std::string, std::string, fz::less_insensitive_ascii> const& pairs() const { return segments_; }
 
+	bool empty() const { return segments_.empty(); }
+
 private:
 	std::map<std::string, std::string, fz::less_insensitive_ascii> segments_;
 };
